using System;

namespace Weigelt.GhostDoc.Gui
{
	/// <summary>
	/// Event arguments for <see cref="LinkBoxEventHandler"/>.
	/// </summary>
	public class LinkBoxEventArgs : EventArgs
	{
		private int m_nIndex;
		private object m_objTag;

		/// <summary>
		/// Gets the index of the link.
		/// </summary>
		public int Index
		{
			get { return m_nIndex; }
		}

		/// <summary>
		/// Gets the object that contains data about the link.
		/// </summary>
		public object Tag
		{
			get { return m_objTag; }
		}

		#region ... Constructor ...

		/// <summary>
		/// Creates a new <see cref="LinkBoxEventArgs"/> instance.
		/// </summary>
		/// <param name="index">Index of the link.</param>
		/// <param name="tag">Object containing data about the link involved in the event.</param>
		public LinkBoxEventArgs(int index, object tag)
		{
			m_nIndex=index;
			m_objTag=tag;
		}

		#endregion
	}

	/// <summary>
	/// Delegate for events of the <see cref="LinkBox"/> control.
	/// </summary>
	public delegate void LinkBoxEventHandler(object sender, LinkBoxEventArgs e);
}
